// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Error.h
//
// Abstract interface definition for global Error object.
//
// (c) 1997 European Space Agency - written by Marco Beijersbergen
//                                  modified by Jorgo Bakker

#ifndef Error_h
#define Error_h

#include <string>
#include <iostream>
#include <sstream>

#include "ErrorHandler.h"
#include "Msg.h"

//----------------------------------------------------------------
// Class Error
//
// Abstract interface definition for a global error object
//----------------------------------------------------------------

class Error : public Msg {

  public:

    virtual ~Error() {}

    // Register a new error handler (if available), and return the previous one
    virtual ErrorHandler* handler(ErrorHandler* =0) = 0;

    // Set the name of the client to be used in messages.
    virtual void name(const std::string&) = 0;

    // Return the name of the client.
    virtual const std::string & name() const = 0;

    // Set the global verbosity level.
    virtual void verbosity(Verbosity level) = 0;

    // Return the global verbosity level.
    virtual Verbosity verbosity() const = 0;

    // Return the verbosity level of a particular layer.
    virtual Verbosity verbosity(Layer layer) const = 0;

    // Fatal error: this is so bad, nobody can continue
    virtual void fatal(Code code) = 0;

    // Error: I can't continue, but my caller could
    virtual void error(Code code) = 0;

    // Warning: report this message, but I will continue
    virtual void warning(Code code) = 0;

    // Message: report this message if the verbosity is higher than level
    virtual void message(Layer layer, Verbosity level) = 0;

    // Ignore warnings of type Code
    virtual void ignoreWarning(Code code) = 0;

    // Allow warnings of type Code
    virtual void allowWarning(Code code) = 0;

    // Return the commandline switches
    virtual std::string asCommandLine()=0;

    virtual std::ostream& errstream() = 0;
};

extern Error& errHandler;

#endif

