// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/**-*-C++-*-*******************************************************************
 *
 *  MessageFormatter.h                          XMM Science Analysis Subsystem
 *
 *  Class to encode/decode various types of warning/error message, so that
 *  they may be passed via the "std::cerr" stream to the calling process.
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *  (c) 2000 ESA  -  Modified by Jorgo Bakker, BSC
 *  (c) 2003 ESA  -  Refactored by Jorgo Bakker, BSC
 *
 *  $Id: MessageFormatter.h,v 1.3 2003/01/28 10:45:04 jbakker Exp $
 *
 *****************************************************************************/

#ifndef MessageFormatter_h
#define MessageFormatter_h

#include "MessageHandler.h"
#include <string>


// TODO: redocument refactoring of this class... above does not apply no more?
class MessageFormatter : public MessageHandler
{
public:
  MessageFormatter(){}
  virtual ~MessageFormatter() {}

  /*--------------------------------------------------------------------------
    encoding...
    -------------------------------------------------------------------------*/
  virtual void message(const std::string& name,
		       const std::string& text) =0;

  virtual void warning(const std::string& name,
		       const std::string& code, 
		       const std::string& text) =0;

  virtual void error(const std::string& name,
		     const std::string& code, 
		     const std::string& text) =0;

  virtual void fatal(const std::string& name,
		     const std::string& code, 
		     const std::string& text) =0;

  /*--------------------------------------------------------------------------
    decoding...
    -------------------------------------------------------------------------*/
  /**
     Decodes the data and passes it to the registered MessageHandler
  */
  virtual void decode() =0;

  /**
     The MessageHandler that listens to decode messages
   */
  virtual void setDecodeListener(MessageHandler* handler=0) =0;

private:
  // disabled:
  MessageFormatter(const MessageFormatter&);
  MessageFormatter& operator=(const MessageFormatter&);
};

#endif
