// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      SuppressHandler.h
// Author:    jbakker
// Generated: Tue Feb  8 17:35:17 MET 2000

#ifndef SuppressHandler_h
#define SuppressHandler_h

#include "Msg.h"

#include <string>
#include <map>


class SuppressHandler
{
public:
  SuppressHandler();
  ~SuppressHandler();

  /* adds Code to the std::list of ignored Codes. Note:
     - Code can be a std::string "NoAttitudeData"
     - Code can be empty (""), meaning all Code must be ignored
     - Code can contain a number ("N"), meaning after N occurences, all Code
       must be ignored
  */
  void ignore(const Code& c);

  /* removes Code from the std::list of ignored Codes. Note:
     -if Code is empty (""), we go back to default state
     -if Code is a number ("N"), allow N Codes to appear
  */
  void allow(const Code& c);

  /* true if we want to show this message */
  bool suppress(const Code& c);

  /* create statistics skipped Codes */
  std::string statistics();

  /* reset the internals to its starting state (with possible Codes set) */
  void reset();

  /* create s std::string of command line switches */
  std::string options();

protected:
  // only derived classes can use these

private:
  // member functions
  SuppressHandler(const SuppressHandler&);      // copy constructor (disabled)
  SuppressHandler& operator=(const SuppressHandler&); // assignment (disabled)


  // member data
  std::map<Code,int> _map;        // statistics
  std::map<Code,int> _list;       // all codes that need to be shut up
  bool          _all;        // is set when all warnings must be silenced
  int           _number;     // number of times any warning may occur before
                             // it is silenced
};



#endif
