// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*
    error.cc

    Implementation of the C interface to the error library.
*/

#include "errstr.h"
#include "error.h"
#include <cstdio>
#include <cstdarg>

void sas_message(MsgLayer layer, MsgLevel level, const char* fmt, ...)
{
  char s[4096];

  va_list args;
  va_start(args,fmt);
  vsprintf(s,fmt,args);
  va_end(args);

  errstr << s << Sas::message(Msg::Layer(layer),Msg::Verbosity(level));
}

void sas_warning(const char* code, const char* fmt, ...)
{
  char s[4096];

  va_list args;
  va_start(args,fmt);
  vsprintf(s,fmt,args);
  va_end(args);

  errstr << s << Sas::warning(code);
}

void sas_error(const char* code, const char* fmt, ...)
{
  char s[4096];

  va_list args;
  va_start(args,fmt);
  vsprintf(s,fmt,args);
  va_end(args);

  errstr << s << Sas::error(code);
}

void sas_fatal(const char* code, const char* fmt, ...)
{
  char s[4096];

  va_list args;
  va_start(args,fmt);
  vsprintf(s,fmt,args);
  va_end(args);

  errstr << s << Sas::fatal(code);
}

