// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/*
    errorhandling_implementation.cc

*/


#include <cstdlib>	// C

#include <string>	// C++
#include <list>

#include <f90cxx.h>	// SAS
#include <stringutil.h>
#include <Tracer.h>
#include "errstr.h"

// Define here the module variable errstr
extern F90MODVARDEF(char,errorhandling,errstr[4096]);

static std::string msg(const char* text, int textLen)
{
  PROC;

  // If a text was provided, convert it to a std::string;
  // otherwise use the contents of the module variable errstr.
  /*
    Bug: seg fault when taking 4096 characters. It is unclear whether
    the problem lies in the std::string constructor, or somewhere else in the
    code.

    Fix: pass len-1 characters to the constructor
   */
  RETURN (text ?
	 std::string(text,textLen) :
	 trim(std::string(F90MODVAR(errorhandling,errstr),4095)) );
}

F90PROCDEF(void,fatal)(
			const char *	codeID,
			const char * 	text,
			int		codeIDLen,
			int		textLen )
{
  errstr << msg(text,textLen) << Sas::fatal(std::string(codeID,codeIDLen));
}


F90PROCDEF(void,error)(
			const char *	codeID,
			const char *	text,
			int		codeIDLen,
			int		textLen )
{
  errstr << msg(text,textLen) << Sas::error(std::string(codeID,codeIDLen));
}


F90PROCDEF(void,warning)(
			const char *	codeID,
			const char *	text,
			int		codeIDLen,
			int		textLen )
{
  errstr << msg(text,textLen) << Sas::warning(std::string(codeID,codeIDLen));
}

F90PROCDEF(int,verbosity)(
			int&		layer)
{
  return errHandler.verbosity(Msg::Layer(layer));
}

F90PROCDEF(void,message)(
			int&		layer,
			int&		level,
			const char*	text,
			int		textLen )
{
  errstr << msg(text,textLen) << Sas::message(Msg::Layer(layer),level);
}


// Future extensions that can be used in combination with exception handling
// in the libraries.
/*
F90PROCDEF(char*,status)( void )
{
  PROC
  RETURN "";
}

F90PROCDEF(void,try)( void )
{
  PROC
  ENDPROC
}
*/
